﻿using DerpingDrivers.Util;
using MahApps.Metro.Controls;

namespace DerpingDrivers
{
    /// <summary>
    ///     Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : MetroWindow
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        /// <summary>
        ///     Gets Operating System Architecture display name.
        /// </summary>
        public string OsArchitecture =>
            OsVersionInfo.OsBits == OsVersionInfo.SoftwareArchitecture.Bit64 ? "64-bit" : "32-bit";

        /// <summary>
        ///     Gets Operating System display name.
        /// </summary>
        public string OsVersionName => $"{OsVersionInfo.Name} {OsVersionInfo.Edition}";

        /// <summary>
        ///     Gets Operating System build number.
        /// </summary>
        public string OsVersion => OsVersionInfo.VersionString;

        /// <summary>
        ///     Gets Boot mode (Legacy BIOS, UEFI).
        /// </summary>
        public string BootMode => UEFIHelper.IsRunningInUEFIMode ? "UEFI" : "Legacy BIOS";

        /// <summary>
        ///     Gets Secure Boot status.
        /// </summary>
        public string SecureBootEnabled => UEFIHelper.IsRunningInUEFIMode
            ? (UEFIHelper.IsSecureBootEnabled ? "Enabled" : "Disabled")
            : "Not available";

        /// <summary>
        ///     Gets OS upgrade status.
        /// </summary>
        public string OsUpgradeStatus =>
            OsUpgradeDetection.IsGrandfathered ? "In-place upgraded" : "Clean installation";
    }
}